@@ -4,7 +4,7 @@ from base64 import b64decode, b64encode
 
 import httpx
 
-from .settings import API_URL, APPLICATION_ID, CLIENT_SECRET, CLIENT_ID, MERCHANT_UID
+from .settings import API_URL, APPLICATION_ID, CLIENT_SECRET, DEFAULT_IP_ADDRESS, CLIENT_ID, MERCHANT_UID
 from .adumo_types import AccountHolder, Card
 
 from .constants import FAILED, SUCCESS
@@ -38,8 +38,11 @@ class Adumo:
         return access_token
 
     def check_3d_enrollment(
-        self, account_holder: AccountHolder, card: Card, amount: str, ip_address: str
+        self, account_holder: AccountHolder, card: Card, amount: str, ip_address: str = None
     ):
+        if ip_address is None:
+            ip_address = DEFAULT_IP_ADDRESS
+
         transaction_id = uuid.uuid4().__str__()
         request = {
             "applicationUid": APPLICATION_ID,
@@ -74,7 +77,7 @@ class Adumo:
         if not three_d_secure_enrolled:
             return {
                 "status": FAILED,
-                transaction_id: transaction_id,
+                "transaction_id": transaction_id,
                 "message": "Card not Enrolled in 3ds, cannot process payment",
             }
         md = self.encode_md(transaction_id, amount, card.security_code)
